REFLECTOR_A = "EJMZALYXVBWFCRQUONTSPIKHGD"
REFLECTOR_B = "YRUHQSLDPXNGOKMIEBFZCWVJAT"
REFLECTOR_C = "FVPJIAOYEDRZXWGCTKUQSBNMHL"

REFLECTOR_B_THIN = "ENKQAUYWJICOPBLMDXZVFTHRGS"
REFLECTOR_C_THIN = "RDOBJNTKVEHMLFCWZAXGYIPSUQ"
