# Wehrmacht/Luftwaffe rotors I–V
ROTOR_I = ("EKMFLGDQVZNTOWYHXUSPAIBRCJ", "Q")
ROTOR_II = ("AJDKSIRUXBLHWTMCQGZNPYFVOE", "E")
ROTOR_III = ("BDFHJLCPRTXVZNYEIWGAKMUSQO", "V")
ROTOR_IV = ("ESOVPZJAYQUIRHXLNFTGKDCMWB", "J")
ROTOR_V = ("VZBRGITYUPSDNHLXAWMJQOFECK", "Z")

# Kriegsmarine additional rotors VI–VIII
ROTOR_VI = ("JPGVOUMFYQBENHZRDKASXLICTW", "Z")
ROTOR_VII = ("NZJHGRCXMYSWBOUFAIVLPEKQDT", "Z")
ROTOR_VIII = ("FKQHTLXOCBJSPDZRAMEWNIUYGV", "Z")

# M4 Greek rotors (do NOT rotate)
ROTOR_BETA = ("LEYJVCNIXWPBQMDRTAKZGFUHOS", None)
ROTOR_GAMMA = ("FSOKANUERHMBTIYCWLQPZXVGJD", None)
